import router from './router'
import store from './store'
import { Message } from 'element-ui'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css' // progress bar style
import { getToken } from '@/utils/auth'
import de from "element-ui/src/locale/lang/de"; // get token from cookie
// import getPageTitle from '@/utils/get-page-title'

NProgress.configure({ showSpinner: false }) // NProgress Configuration

const whiteList = ['/auth-redirect', '/bind', '/register', '/login', '/forgetPwd']

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (getToken()) {
    /* has token*/
    if (to.path === '/login') {
      next()
      NProgress.done()
    } else {
      if (store.getters.roles.length === 0) {
        // 判断当前用户是否已拉取完user_info信息

        store.dispatch('GetInfo').then(res => {
          // 判断用户是否有权限 有角色
          if (res.data.permissions && res.data.permissions.length > 0) {
            // 拉取user_info
            const roles = res.data.roles
            store.dispatch('GenerateRoutes', { roles }).then((routers) => {
              // 判断用户是否有路由
              if (routers.accessedRoutes && routers.accessedRoutes.length > 0 && routers.getRouters && routers.getRouters.length > 0) {
                // 测试 默认静态页面
                // store.dispatch('permission/generateRoutes', { roles }).then(accessRoutes => {
                // 根据roles权限生成可访问的路由表
                router.addRoutes(routers.accessedRoutes) // 动态添加可访问路由表
                next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
              } else {
                alert('用户无权限')
                store.dispatch('FedLogOut').then(() => {
                  next({ path: '/login' })
                  // window.location.href = `${process.env.VUE_APP_LOGIN}?redirect=${to.fullPath}&reLocation=${process.env.VUE_APP_NQ}`
                })
              }
            })
          } else {
            alert('用户无权限')
            store.dispatch('FedLogOut').then(() => {
              next({ path: '/login' })
              // window.location.href = `${process.env.VUE_APP_LOGIN}?redirect=${to.fullPath}&reLocation=${process.env.VUE_APP_NQ}`
            })
          }
        })
          .catch(err => {
            store.dispatch('FedLogOut').then(() => {
              Message.error(err)
              next({ path: '/login' })
              // window.location.href = `${process.env.VUE_APP_LOGIN}?redirect=${to.fullPath}&reLocation=${process.env.VUE_APP_NQ}`
            })
          })
      } else {
        next()
        // 没有动态改变权限的需求可直接next() 删除下方权限判断 ↓
        // if (hasPermission(store.getters.roles, to.meta.roles)) {
        //   next()
        // } else {
        //   next({ path: '/401', replace: true, query: { noGoBack: true }})
        // }
        // 可删 ↑
      }
    }
  } else {
    // 临时跳转
    // store.commit('SET_ROUTES', {})
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      next()
    } else {
      // 临时跳转
      next({ path: '/login' })
      // next(`http://login.court.com/login?redirect=${to.fullPath}`) // 否则全部重定向到登录页
      // window.location.href = `${process.env.VUE_APP_LOGIN}?redirect=${to.fullPath}&reLocation=${process.env.VUE_APP_ZT}`
      // next()
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  // finish progress bar
  NProgress.done()
})
